@@ -20,6 +20,7 @@ import (
 	"github.com/anchore/grype/grype/store"
 	"github.com/anchore/grype/grype/version"
 	"github.com/anchore/grype/grype/vulnerability"
+	"github.com/anchore/syft/syft/cpe"
 	"github.com/anchore/syft/syft/linux"
 	syftPkg "github.com/anchore/syft/syft/pkg"
 )
@@ -277,8 +278,8 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 		Type:    syftPkg.DebPkg,
 	}
 
-	mustCPE := func(c string) syftPkg.CPE {
-		cp, err := syftPkg.NewCPE(c)
+	mustCPE := func(c string) cpe.CPE {
+		cp, err := cpe.New(c)
 		if err != nil {
 			t.Fatal(err)
 		}
@@ -289,7 +290,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 		ID:      pkg.ID(uuid.NewString()),
 		Name:    "activerecord",
 		Version: "3.7.5",
-		CPEs: []syftPkg.CPE{
+		CPEs: []cpe.CPE{
 			mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 		},
 		Type:     syftPkg.GemPkg,
@@ -363,7 +364,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 						ID:                "CVE-2014-fake-1",
 						Namespace:         "debian:distro:debian:8",
 						PackageQualifiers: []qualifier.Qualifier{},
-						CPEs:              []syftPkg.CPE{},
+						CPEs:              []cpe.CPE{},
 						Advisories:        []vulnerability.Advisory{},
 					},
 					Package: neutron2013Pkg,
@@ -416,7 +417,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 						ID:                "CVE-2014-fake-1",
 						Namespace:         "debian:distro:debian:8",
 						PackageQualifiers: []qualifier.Qualifier{},
-						CPEs:              []syftPkg.CPE{},
+						CPEs:              []cpe.CPE{},
 						Advisories:        []vulnerability.Advisory{},
 					},
 					Package: neutron2013Pkg,
@@ -463,7 +464,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 						Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
 						ID:         "CVE-2014-fake-3",
 						Namespace:  "nvd:cpe",
-						CPEs: []syftPkg.CPE{
+						CPEs: []cpe.CPE{
 							mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 						},
 						PackageQualifiers: []qualifier.Qualifier{},
@@ -504,7 +505,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 						},
 						PackageQualifiers: []qualifier.Qualifier{},
 						Advisories:        []vulnerability.Advisory{},
-						CPEs:              []syftPkg.CPE{},
+						CPEs:              []cpe.CPE{},
 					},
 					Package: activerecordPkg,
 					Details: match.Details{
@@ -552,11 +553,17 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 						Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
 						ID:         "CVE-2014-fake-3",
 						Namespace:  "nvd:cpe",
-						CPEs: []syftPkg.CPE{
+						CPEs: []cpe.CPE{
 							mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 						},
 						PackageQualifiers: []qualifier.Qualifier{},
 						Advisories:        []vulnerability.Advisory{},
+						RelatedVulnerabilities: []vulnerability.Reference{
+							{
+								ID:        "GHSA-2014-fake-3",
+								Namespace: "github:language:ruby",
+							},
+						},
 					},
 					Package: activerecordPkg,
 					Details: match.Details{
@@ -627,7 +634,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 						Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
 						ID:         "CVE-2014-fake-3",
 						Namespace:  "nvd:cpe",
-						CPEs: []syftPkg.CPE{
+						CPEs: []cpe.CPE{
 							mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 						},
 						PackageQualifiers: []qualifier.Qualifier{},
@@ -695,7 +702,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 							Constraint:        version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
 							ID:                "CVE-2014-fake-3",
 							Namespace:         "nvd:cpe",
-							CPEs:              []syftPkg.CPE{},
+							CPEs:              []cpe.CPE{},
 							PackageQualifiers: []qualifier.Qualifier{},
 							Advisories:        []vulnerability.Advisory{},
 							RelatedVulnerabilities: []vulnerability.Reference{
@@ -760,7 +767,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 						},
 						PackageQualifiers: []qualifier.Qualifier{},
 						Advisories:        []vulnerability.Advisory{},
-						CPEs:              []syftPkg.CPE{},
+						CPEs:              []cpe.CPE{},
 					},
 					Package: activerecordPkg,
 					Details: match.Details{
@@ -792,7 +799,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 							Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
 							ID:         "CVE-2014-fake-3",
 							Namespace:  "nvd:cpe",
-							CPEs: []syftPkg.CPE{
+							CPEs: []cpe.CPE{
 								mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 							},
 							PackageQualifiers: []qualifier.Qualifier{},
